<?php

namespace Drupal\drupal_slider\Plugin\views\style;

use Drupal\Core\Form\FormStateInterface;
use Drupal\views\Plugin\views\style\StylePluginBase;

/**
 * @ingroup views_style_plugins
 *
 * @ViewsStyle(
 *   id = "drupal_slider",
 *   title = @Translation("Drupal Slider"),
 *   help = @Translation("Displays a view as a Slider, using the Drupal Slider + Slider Pro jQuery plugin."),
 *   theme = "drupal_slider_views_style",
 *   theme_file = "drupal_slider_views.theme.inc",
 *   display_types = {"normal"}
 * )
 */
class DrupalSlider extends StylePluginBase {

  protected $usesRowPlugin = TRUE;

  protected $usesRowClass = FALSE;

  protected $usesGrouping = FALSE;

  protected $usesFields = TRUE;

  /**
   *
   */
  protected function defineOptions() {
    $options = parent::defineOptions();
    $options['general'] = ['contains' => []];
/*    $options['general']['contains']['width'] = ['default' => 950];
    $options['general']['contains']['height'] = ['default' => 500];*/
    $options['general']['contains']['arrows'] = ['default' => 1];
    $options['general']['contains']['buttons'] = ['default' => 1];
    $options['general']['contains']['autoplay'] = ['default' => 1];
    $options['general']['contains']['shuffle'] = ['default' => 0];
    $options['general']['contains']['carousel'] = ['default' => 0];
    return $options;
  }

  /**
   *
   */
  public function buildOptionsForm(&$form, FormStateInterface $form_state) {
    parent::buildOptionsForm($form, $form_state);
    $fields = $this->getAvailableFields();
    if (empty($fields)) {
      drupal_set_message($this->t('To configure Drupal Slider you have to add at least one field'), 'error');
      return $form;
    }

    $form['general'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('General Settings'),
      '#open' => TRUE,
    ];
/*    $form['general']['width'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Width'),
      '#description' => 'The width of the slider. Eg 200px or 50%. Leave it to use image width',
      '#default_value' => $this->options['general']['width'],
    ];
    $form['general']['height'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Height'),
      '#default_value' => $this->options['general']['height'],
      '#description' => 'The height of the slider. Eg 200px. Leave it to use image width',
    ];*/
    $form['general']['arrows'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Arrows'),
      '#default_value' => $this->options['general']['arrows'],
      '#description' => $this->t('Navigation arrows on slide will be created.'),
    ];
    $form['general']['buttons'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Buttons'),
      '#default_value' => $this->options['general']['buttons'],
      '#description' => $this->t('Shows current slide position'),
    ];
    $form['general']['autoplay'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Autoplay'),
      '#default_value' => $this->options['general']['autoplay'],
      '#description' => $this->t('Autoplay the slides.'),
    ];
    $form['general']['shuffle'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Shuffle the slides'),
      '#default_value' => $this->options['general']['shuffle'],
      '#description' => $this->t('Shuffles the slides.'),
    ];     
    $form['general']['carousel'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Show carousel instead of slider'),
      '#default_value' => $this->options['general']['carousel'],
      '#description' => $this->t('By checking this it will turn into carousel. The image width should be less than window size.'),
    ];    

  }

  /**
   * Returns option list of fields available on view.
   */
  protected function getAvailableFields() {
    $view = $this->view;
    return $view->display_handler->getFieldLabels();
  }

}
